@@ -5,27 +5,31 @@
 //! Please rely on updating induidual threads if you do not need *all* posts from a thead.
 //!
 //! # Time
-//! 
-//! Due to API constraints, the boards is built rather slowly. 
-//! 
+//!
+//! Due to API constraints, a board is built rather slowly.
+//!
 //! It is recommended to update a board in intervals of no less than than 10 minutes.
-//! 
+//!
 //! # Example: Building a board and updating it
-//! ```rust
+//! ```rust,ignore
+//! use dot4ch::{Client, Update, board::Board}
 //! // Building the /g/ board
-//! let board = Board::build(&client, "g")
-//! 
+//! let board = Board::build(&client, "g").await.unwrap();
+//!
 //! /* Do something with the board */
-//! 
+//!
 //! // After a long interval, we update it.
 //! let g = board.update(&client);
 //! println!("{:#?}", g);
-//! ``` 
+//! ```
 
-use crate::{thread::Thread, threadlist::Catalog, Update};
+use crate::{thread::Thread, threadlist::Catalog, Dot4chClient, Update};
 use async_trait::async_trait;
 use log::info;
+
+/// Type alias for not wrting Arc<Mute<Client>>
 type CrateClient = Arc<tokio::sync::Mutex<crate::Client>>;
+
 use std::{
     collections::HashMap,
     io::{self, Write},
@@ -51,20 +55,24 @@ impl Board {
     /// A typical board of ~150 threads takes 5+ minutes to cache.
     ///
     /// It is advised to build this only once due to its long wait times caused by API cooldowns.
-    pub async fn build(client: &CrateClient, board: &str) -> crate::Result<Self> {
+    ///
+    /// # Errors
+    ///
+    /// This function will return an error if request to get a new `Catalog` fails.
+    pub async fn build(client: &Dot4chClient, board: &str) -> crate::Result<Self> {
         writeln!(io::stdout(), "Building Board! Please wait.")?;
-        let catalog = Catalog::new(&client, board).await?;
+        let catalog = Catalog::new(client, board).await?;
         let ids: Vec<_> = catalog
             .all_pages()
             .into_iter()
-            .flat_map(|f| f.threads())
+            .flat_map(crate::threadlist::Page::threads)
             .map(|thread| thread.id())
             .collect();
 
         info!("Number of threads: {}", ids.len());
         let mut threads = vec![];
         for (idx, id) in ids.iter().enumerate() {
-            threads.push(Thread::new(&client, board, *id).await?);
+            threads.push(Thread::new(client, board, *id).await?);
             info!("Pushed Thread: {}/{}", idx + 1, ids.len())
         }
 
@@ -80,9 +88,8 @@ impl Board {
     }
 
     /// Returns a specific Thread from the Board cache.
-    pub fn get(self, k: u32) -> Option<Thread> {
-        let f = self.threads.get(&k);
-        f.cloned()
+    pub fn get(&self, k: u32) -> Option<&'_ Thread> {
+        self.threads.get(&k)
     }
 
     /// Inserts a new thread into a cache.
@@ -101,7 +108,7 @@ impl Board {
 
 #[async_trait(?Send)]
 impl Update for Board {
-    type Output = Board;
+    type Output = Self;
     /// Returns an updated board.
     ///
     /// It is recommended to call this infrequently due to API calls having cooldowns.
@@ -111,18 +118,18 @@ impl Update for Board {
         // get the ID's of all the threads we need
         // we have to call this again because there might be new thread that need to be added.
         writeln!(io::stdout(), "Updating Board. Please wait..")?;
-        let catalog = Catalog::new(&client, &self.board).await?;
+        let catalog = Catalog::new(client, &self.board).await?;
         let ids: Vec<_> = catalog
             .all_pages()
             .into_iter()
-            .flat_map(|f| f.threads())
+            .flat_map(crate::threadlist::Page::threads)
             .map(|thread| thread.id())
             .collect();
 
         let mut threads = vec![];
         for (num, (id, thread)) in self.threads.into_iter().enumerate() {
             // update all threads with the ID
-            threads.push(thread.update(&client).await?);
+            threads.push(thread.update(client).await?);
             info!(
                 "Updating thread: {}\t Threads updated: {}/{}",
                 id,
