@@ -2,19 +2,24 @@
 //!
 //! Some of the fields here are optional
 //!
-//! Posts are usually used in `Thread`s which is why they do not have a `new()`.
+//! Posts are usually used in `Thread`s which is why they do not have a `new()` but they do have an `Default` implementation.
 //!
-//! Making an entire `Thread` and searching is preferred since it too uses a single request
+//! ## 4chan API:
+//! /[board]/thread/[op ID].json files are a representation of a single OP and all the replies, which form a thread.
+//!
+//! ```rust
+//! use dot4ch::post::Post;
 //!
-//! ```rust,no_run
 //! let z = Post::default();
+//!
 //! println!("{}", z.id());
-//! asserteq!(z.id(), 0);
+//!
+//! assert_eq!(z.id(), 0);
 //! ```
 
-use std::fmt::{Display, Formatter};
 use crate::default;
 use serde::{Deserialize, Serialize};
+use std::fmt::{Display, Formatter};
 
 /// The Post represents a derserialized post from a thread.
 #[derive(Debug, Clone, Serialize, Deserialize, Default)]
@@ -39,7 +44,7 @@ pub struct Post {
     now: String,
 
     /// UNIX timestamp the post was created
-    time: u64,
+    time: i64,
 
     /// Name user posted with. Defaults to `Anonymous`
     #[serde(default = "default::<String>")]
@@ -175,17 +180,19 @@ pub struct Post {
 }
 
 impl Post {
-    /// Gets the post number of a Post
+    /// Returns the post number of a Post
     pub fn id(&self) -> u32 {
         self.no
     }
 
-    /// Get the subject from the text
+    /// Returns the subject from the text.
+    ///
+    /// Returns an empty str if there isnt any.
     pub fn subject(&self) -> &str {
         &self.sub
     }
 
-    /// Gets the time from Post
+    /// Returns the time from Post
     ///
     /// format:
     /// MM/DD/YY(Day)HH:MM (:SS on some boards), EST/EDT timezone
@@ -193,27 +200,29 @@ impl Post {
         &self.now
     }
 
-    /// Gets the comment from the Post
+    /// Returns the comment from the Post
     pub fn content(&self) -> &str {
         &self.com
     }
 
-    /// Gets the filename
+    /// Returns the filename if there is one or an empty string otherwise.
     pub fn filename(&self) -> &str {
         &self.filename
     }
 
-    /// Gets the filename's extension
+    /// Returns the filename's extension if there is a file.
+    ///
+    /// Returns an empty &str otherwise.
     pub fn ext(&self) -> &str {
         &self.ext
     }
 
-    /// Gets the number of replies to the Post
+    /// Returns the number of replies to the Post
     pub fn replies(&self) -> u32 {
         self.replies
     }
 
-    /// Check if the OP Post is archived.
+    /// Returns true if the post is archived. False othwrwise.
     pub fn archived(&self) -> bool {
         if self.archived == 1 {
             return true;
@@ -236,14 +245,97 @@ impl Post {
         if !self.filename.is_empty() && !self.ext.is_empty() {
             Some(format!(
                 "https://i.4cdn.org/{}/{}{}",
-                board,
-                &self.tim,
-                &self.ext
+                board, &self.tim, &self.ext
             ))
         } else {
             None
         }
     }
+
+    /// Returns a UNIX Timestamp of when the post was created
+    pub fn post_time(&self) -> i64 {
+        self.time
+    }
+
+    /// Returns a true if the thread is pinned
+    pub fn sticky(&self) -> bool {
+        if self.sticky != 0 {
+            return true;
+        }
+        false
+    }
+
+    /// Returns true if the thread is closed to replies
+    pub fn closed(&self) -> bool {
+        if self.closed != 0 {
+            return true;
+        }
+        false
+    }
+
+    /// Returns the tripcode if the poster has one. Returns `None` otherwise.
+    pub fn tripcode(&self) -> Option<&str> {
+        if self.trip.is_empty() {
+            return None;
+        }
+        Some(&self.trip)
+    }
+
+    /// Returns the capcode identifier for a post if there is one. `None` otherwise.
+    pub fn capcode(&self) -> Option<&str> {
+        if self.capcode.is_empty() {
+            return None;
+        }
+        Some(&self.capcode)
+    }
+
+    /// Returns the poster's country name if there is one avaliable. `None` otherwise.
+    pub fn country(&self) -> Option<&str> {
+        if self.country_name.is_empty() {
+            return None;
+        }
+        Some(&self.country_name)
+    }
+
+    /// Returns the post's file's MD5 hash if there is one.
+    pub fn md5hash(&self) -> Option<&str> {
+        if self.md5.is_empty() {
+            return None;
+        }
+        Some(&self.md5)
+    }
+
+    /// Returns true if the file in the post was deleted.
+    pub fn file_deleted(&self) -> bool {
+        if self.filedeleted != 0 {
+            return true;
+        }
+        false
+    }
+
+    /// Returns a filesize of a post if it has one.
+    pub fn filesize(&self) -> Option<u32> {
+        if self.fsize != 0 {
+            return Some(self.fsize);
+        }
+        None
+    }
+
+    /// Returns true if the thread has reached image limit, false otherwise
+    pub fn image_limit(&self) -> bool {
+        if self.imagelimit != 0 {
+            return true;
+        }
+        false
+    }
+
+    /// Returns true if the thread has reached bump limit, false otherwise
+    pub fn bump_limit(&self) -> bool {
+        if self.bumplimit != 0 {
+            return true;
+        }
+        false
+    }
 }
 
 impl Display for Post {
