@@ -15,37 +15,55 @@
 //! - The number of replies a thread has
 //!
 
-use crate::{header, IfModifiedSince, Update};
+use crate::{header, Dot4chClient, IfModifiedSince, Update};
 use async_trait::async_trait;
 use chrono::{DateTime, Duration, NaiveDateTime, Utc};
 use log::debug;
 use reqwest::{header::IF_MODIFIED_SINCE, Response, StatusCode};
 use serde::{Deserialize, Serialize};
-use std::fmt::{Display, Formatter};
+use std::fmt::{self, Display, Formatter};
 use tokio::time;
 
-type Client = std::sync::Arc<tokio::sync::Mutex<crate::Client>>;
-
 /// A summarized list of all threads on a board including
 /// thread numbers, their modification time and reply count.
 ///
 /// # Example
 ///
-/// ```rust,no_run
-/// let list1 = Catalog::new(&client, "g")?;
-/// println!("{:?}", resp.threads)
+/// ```rust,ignore
+/// use dot4ch::threadlist::Catalog;
+///
+/// let catalog = Catalog::new(&client, "g").await?;
+///
+/// // prints the first page
+/// println!("{:?}", catalog.page(1));
 /// ```
 ///
 /// to get all threads from catalog
 #[derive(Debug)]
 pub struct Catalog {
+    /// The board of the catalog
     board: String,
+    /// The pages of the catalog which contain threads
     threads: Vec<Page>,
+    /// The time when catalog was accessed
     last_accessed: DateTime<Utc>,
 }
 
-#[derive(Debug, Deserialize, Serialize)]
-/// a Page in the catalog.
+impl Default for Catalog {
+    fn default() -> Self {
+        Self {
+            board: String::new(),
+            threads: vec![Page::default()],
+            last_accessed: Utc::now(),
+        }
+    }
+}
+
+#[derive(Debug, Deserialize, Serialize, Default)]
+/// A Page in the catalog.
+/// Pages contain their own number and a vector or `CatalogThreads`
+///
+/// This is usually the intermediate between a Catalog and a `CatalogThread`
 pub struct Page {
     /// The page number that the following thread array is on
     page: u8,
@@ -66,28 +84,25 @@ impl Page {
 }
 
 impl Display for Catalog {
-    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         let fmt = format!(
             "Board: /{}/\nLast accessed: {}\nPages: {}",
             self.board,
             self.last_accessed,
-            self.threads
-                .iter()
-                .map(|x| x.to_string())
-                .collect::<String>()
+            self.threads.iter().map(Page::to_string).collect::<String>()
         );
         write!(f, "{}", fmt)
     }
 }
 
 impl Display for Page {
-    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         let fmt = format!(
             "\nPage Number: {}\nThreads: {}",
             self.page,
             self.threads
                 .iter()
-                .map(|thread| thread.to_string())
+                .map(CatalogThread::to_string)
                 .collect::<String>()
         );
         write!(f, "{}", fmt)
@@ -96,9 +111,9 @@ impl Display for Page {
 
 #[async_trait(?Send)]
 impl Update for Catalog {
-    type Output = Catalog;
+    type Output = Self;
     /// Returns an updated catalog.
-    async fn update(mut self, client: &Client) -> crate::Result<Catalog> {
+    async fn update(mut self, client: &Dot4chClient) -> crate::Result<Self> {
         let curr = Utc::now().signed_duration_since(self.last_accessed);
         if curr < Duration::seconds(10) {
             debug!(
@@ -107,7 +122,7 @@ impl Update for Catalog {
             );
             let dur = Duration::seconds(10).checked_sub(&curr);
             match dur {
-                Some(time) => time::sleep(time.to_std().unwrap()).await,
+                Some(time) => time::sleep(time.to_std()?).await,
                 None => return Err(From::from("Could not subtract time in Catalog")),
             }
         }
@@ -115,11 +130,11 @@ impl Update for Catalog {
         let updated_catalog = {
             let header = header(client).await;
             let get_url = format!("https://a.4cdn.org/{}/threads.json", self.board);
-            let response = Catalog::fetch(&client, &get_url, &header).await?;
+            let response = Self::fetch(client, &get_url, &header).await?;
             client.lock().await.last_checked = Utc::now();
 
             match response.status() {
-                StatusCode::OK => Catalog::new(&client, &self.board).await?,
+                StatusCode::OK => Self::new(client, &self.board).await?,
                 StatusCode::NOT_MODIFIED => {
                     self.last_accessed = Utc::now();
                     self
@@ -140,7 +155,7 @@ impl Update for Catalog {
 #[async_trait(?Send)]
 impl IfModifiedSince for Catalog {
     async fn fetch(
-        client: &std::sync::Arc<tokio::sync::Mutex<crate::Client>>,
+        client: &Dot4chClient,
         url: &str,
         header: &str,
     ) -> Result<Response, reqwest::Error> {
@@ -159,10 +174,10 @@ impl IfModifiedSince for Catalog {
 impl Catalog {
     /// Returns a new `ThreadList` from a given board.
     ///
-    /// # Error
+    /// # Errors
     ///
     /// This function will return an error if the board isn't valid
-    pub async fn new(client: &Client, board: &str) -> crate::Result<Self> {
+    pub async fn new(client: &Dot4chClient, board: &str) -> crate::Result<Self> {
         let url = format!("https://a.4cdn.org/{}/threads.json", board);
         let threads = client
             .lock()
@@ -194,8 +209,8 @@ impl Catalog {
     /// - Returns a slice of elements if a range is provided.
     ///
     /// # Example
-    /// ```rust,no_run
-    /// let threadlist: ThreadList = /* your threadlist */;
+    /// ```rust,ignore
+    /// let catalog = Catalog::new(client, "g").await?;
     /// println!("{:?}", thread.get(1..4));
     /// ```
     pub fn page(&self, idx: usize) -> Option<&Page> {
@@ -212,19 +227,23 @@ impl Catalog {
 ///
 /// # Example
 ///
-/// ```rust,no_run
-/// let resp = reqwest::get("https://a.4cdn.org/g/threads.json").await?.text().await?;
-/// let threadlist: Vec<CatalogThread> = serde_json::from_str(&resp)?;
-/// let thread = threadlist[1].id();
-/// println!("{}", thread);
+/// ```rust,ignore
+/// use dot4ch::threadlist::CatalogThread;
+///
+/// let thread = CatalogThread::default();
+///
+/// // This prints the empty Catalog thread
+/// let thread_2 = CatalogThread { no: 0, last_modified: 0, replies: 0 };
+///
+/// assert_eq!(thread, thread_2);
 /// ```
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Serialize, Deserialize, Default, PartialEq, Clone, Copy)]
 pub struct CatalogThread {
     /// The OP ID of a thread
     no: u32,
     /// The UNIX timestamp marking the last time the thread was modified
     /// (post added/modified/deleted, thread closed/sticky settings modified)
-    last_modified: u64,
+    last_modified: i64,
     /// A numeric count of the number of replies in the thread
     replies: u32,
 }
@@ -236,7 +255,7 @@ impl CatalogThread {
     }
 
     /// Returns the UNIX timestamp of when the thread was last modified.
-    pub fn last_modified(&self) -> u64 {
+    pub fn last_modified(&self) -> i64 {
         self.last_modified
     }
 
@@ -246,9 +265,9 @@ impl CatalogThread {
     }
 }
 
-impl std::fmt::Display for CatalogThread {
-    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        let g = NaiveDateTime::from_timestamp(self.last_modified as i64, 0);
+impl Display for CatalogThread {
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
+        let g = NaiveDateTime::from_timestamp(self.last_modified, 0);
         let fmt = format!(
             "\n\tThread ID: {} | Last Modified: {} | Number of Replies: {}",
             self.no, g, self.replies
